Please cite `flownetpy` as

```tex
@misc{debsankha_manik_2016_48550,
  author       = {Debsankha Manik},
  title        = {flownetpy: 0.0.9},
  month        = mar,
  year         = 2016,
  doi          = {10.5281/zenodo.48550},
  url          = {http://dx.doi.org/10.5281/zenodo.48550}
}
```
